Acknowledging
=============
``astrospice`` makes heavy use of both the ``astropy`` and ``spiceypy`` packages.
If you use ``astrospice`` for pubished work, please consider citing both of these
packages as per their recommendations:

- https://www.astropy.org/acknowledging.html
- https://spiceypy.readthedocs.io/en/main/#citing-spiceypy
